@@ -8,13 +8,16 @@ echo "" 												>> $EXTENSION/build_order.txt
 [[ $(command -v xslt-config) == "" ]] && echo "Installing libxslt" && extension --install libxslt && echo "Finished libxslt"
 # Optional
 if [[ $INSTALL_OPTIONAL != false ]]; then 
+	[[ $(command -v docbook2man) == "" ]] && echo "Installing docbook_utils" && extension --install docbook_utils && echo "Finished docbook_utils"
+	[ ! -d /usr/share/xml/docbook/schema/dtd/5.* ] && echo "Installing docbook5_xml" && extension --install docbook5_xml && echo "Finished docbook5_xml"
+	[[ $(command -v doxygen) == "" ]] && echo "Installing doxygen" && extension --install doxygen && echo "Finished doxygen"
 	[ ! -f /opt/fop/fop ] && echo "Installing fop" && extension --install fop && echo "Finished fop"
 fi
 
-if [ $BUILD_ALL == "false" ] && [ ! -f /lib/libsigc-2.0.so ]; then
-	echo "libsigcpp" 									>> $EXTENSION/build_order.txt
+if [ $BUILD_ALL == "false" ] && [ ! -f /lib/libsigc-3.0.so ]; then
+	echo "libsigcpp3" 									>> $EXTENSION/build_order.txt
 fi
 if [ $BUILD_ALL == "true" ]; then
-	echo "libsigcpp" 									>> $EXTENSION/build_order.txt
+	echo "libsigcpp3" 									>> $EXTENSION/build_order.txt
 fi
 echo "complete _" 										>> $EXTENSION/build_order.txt
